@@ -11,9 +11,10 @@ def page(func):
         for i in code: # Loop through all items in code
             code[code.index(i)] = i.strip() # strip the indentation away
         code.insert(0, "from ebuilder.ebuilder_core import *") # Make sure it imports ebuilder core
-        code.insert(2, f"{file} = newpage('{file}')") # Add a line that will create a new html page with ebuilder core 'newpage'
-        code.insert(-1, "{file}.final_commit()") # Add the final commit line so it will close the html file
+        code.insert(1, f"{file} = newpage('{file}')") # Add a line that will create a new html page with ebuilder core 'newpage'
+        code.insert(-1, f"{file}.final_commit()") # Add the final commit line so it will close the html file
         code = '\n'.join(code) # Put the code back into a Python function format
+        print(code)
         exec(code) # execute the edited code
         
     return wrapper() # Run the function with all the edits
\ No newline at end of file
